==> testsuite-3.0.51-beta1.tar.gz: testsuite/modules/custom_tests/src/Form/CustomTestsFilterForm.php <==
<?php

namespace Drupal\custom_tests\Form;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Database\Connection;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\custom_tests\LoadResourceService;
use Drupal\testsuite\BaseTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the database logging filter form.
 *
 * @internal
 */
class CustomTestsFilterForm extends FormBase {
  use BaseTrait;

  /**
   * The array of filters.
   *
   * @var array
   */
  public $filters = [
    'action',
    'test',
  ];

  /**
   * The database.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * The messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * The time interface.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $timeInterface;

  /**
   * The Core, Modules and Themes libraries service.
   *
   * @var \Drupal\custom_tests\LoadResourceService
   */
  protected $loadResourceService;

  /**
   * CustomTestsFilterForm constructor.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   Load messenger service.
   * @param \Drupal\Component\Datetime\TimeInterface $timeInterface
   *   The time interface.
   * @param \Drupal\custom_tests\LoadResourceService $loadResourceService
   *   The load resource service.
   */
  public function __construct(
        Connection $connection,
        MessengerInterface $messenger,
        TimeInterface $timeInterface,
        LoadResourceService $loadResourceService
    ) {
    $this->connection = $connection;
    $this->messenger = $messenger;
    $this->timeInterface = $timeInterface;
    $this->loadResourceService = $loadResourceService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
          $container->get('database'),
          $container->get('messenger'),
          $container->get('datetime.time'),
          $container->get('custom_tests.load_resource.service')
      );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'custom_tests_filter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $session_filters = $this->getRequest()->getSession()->get('custom_tests_overview_filter', []);

    $form['filters'] = [
      '#type' => 'details',
      '#title' => $this->t('Filter log messages'),
      '#open' => TRUE,
      '#attached' => [
        'library' => [
          'custom_tests/custom_tests.filters',
        ],
      ],
    ];

    $form['filters']['filters-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'custom-tests-filter-form-wrapper',
      ],
    ];

    $actionDropdown = $form_state->hasValue('action') ? $form_state->getValue('action') : '';
    $action_dropdown = !empty($session_filters['action']) ? $session_filters['action'] : $actionDropdown;

    $form['filters']['filters-container']['action-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'custom-test-action-container',
      ],
    ];
    $form['filters']['filters-container']['action-container']['action'] = [
      '#title' => 'Actions',
      '#type' => 'select',
      '#multiple' => FALSE,
      '#size' => 8,
      '#options' => [
        'filter' => $this->t('Filter'),
        'test' => $this->t('Run Test'),
      ],
      '#default_value' => $action_dropdown,
    ];

    $testDropdown = $form_state->hasValue('test') ? $form_state->getValue('test') : '';
    $test_dropdown = !empty($session_filters['test']) ? $session_filters['test'] : $testDropdown;

    $form['filters']['filters-container']['tests-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'custom-tests-container',
      ],
    ];
    $form['filters']['filters-container']['tests-container']['test'] = [
      '#title' => 'Tests',
      '#type' => 'select',
      '#multiple' => TRUE,
      '#size' => 8,
      '#options' => $this->loadResourceService->getTests(),
      '#default_value' => $test_dropdown,
    ];

    $form['filters']['actions'] = [
      '#type' => 'actions',
      '#attributes' => ['class' => ['container-inline']],
    ];
    $form['filters']['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];
    if (!empty($session_filters)) {
      $form['filters']['actions']['reset'] = [
        '#type' => 'submit',
        '#value' => $this->t('Reset'),
        '#limit_validation_errors' => [],
        '#submit' => ['::resetForm'],
      ];
    }
    return $form;
  }

  /**
   * Selects just the second dropdown to be returned for re-rendering.
   *
   * @param array $form
   *   — An associative array containing the structure of the form.
   *
   * @return array
   *   The renderable element.
   */
  public function getModulesCallback($form) {
    return $form['filters']['filters-container']['module-container'];
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if ($form_state->isValueEmpty('action')) {
      $form_state->setErrorByName('action', $this->t('You must select something to filter by.'));
    }
    if ($form_state->getValue('test') == []) {
      $form_state->setErrorByName('test', $this->t('You must select something to filter by.'));
    }
    foreach ($form_state->getValue('test') as $test) {
      if (!preg_match($this->regex['string'], $test)) {
        $form_state->setErrorByName('test', $this->t('Invalid option.'));
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $session_filters = $this->getRequest()->getSession()->get('custom_tests_overview_filter', []);

    if ($form_state->getValue('action') == 'test') {
      $files = $this->loadResourceService->getResource();
      foreach ($form_state->getValue('test') as $test) {
        if (count($files) > 0) {
          foreach ($files as $file) {
            $classFile = basename($file, '.php');
            if ($test == explode(".", $classFile)[0]) {
              $class = '\Drupal\custom_tests\CustomTSTests\\' . $classFile;
              include_once $file;
              if (class_exists($class)) {
                $obj = new $class();
                $request = $this->getRequest();
                $results = $obj->runTest($request);
                $this->connection->insert('custom_test_item')
                  ->fields(
                  [
                    'test' => $test,
                    'error_report' => $results,
                    'created' => $this->timeInterface->getRequestTime(),
                  ]
                )
                  ->execute();
              }
            }
          }
        }
      }
    }

    foreach ($this->filters as $name) {
      if ($form_state->hasValue($name)) {
        $session_filters[$name] = $form_state->getValue($name);
      }
    }
    $this->getRequest()->getSession()->set('custom_tests_overview_filter', $session_filters);
  }

  /**
   * Resets the filter form.
   */
  public function resetForm() {
    $this->getRequest()->getSession()->remove('custom_tests_overview_filter');
  }

}

==> testsuite-3.0.53-beta1.tar.gz: testsuite/modules/custom_tests/src/Form/CustomTestsFilterForm.php <==
<?php

namespace Drupal\custom_tests\Form;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Database\Connection;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\custom_tests\CustomTestsResourceService;
use Drupal\testsuite\BaseTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the database logging filter form.
 *
 * @internal
 */
class CustomTestsFilterForm extends FormBase {
  use BaseTrait;

  /**
   * The array of filters.
   *
   * @var array
   */
  public $filters = [
    'action',
    'test',
  ];

  /**
   * The database.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * The messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * The time interface.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $timeInterface;

  /**
   * The Core, Modules and Themes libraries service.
   *
   * @var \Drupal\custom_tests\CustomTestsResourceService
   */
  protected $customTestsResourceService;

  /**
   * CustomTestsFilterForm constructor.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   Load messenger service.
   * @param \Drupal\Component\Datetime\TimeInterface $timeInterface
   *   The time interface.
   * @param \Drupal\custom_tests\CustomTestsResourceService $customTestsResourceService
   *   The load resource service.
   */
  public function __construct(
        Connection $connection,
        MessengerInterface $messenger,
        TimeInterface $timeInterface,
        CustomTestsResourceService $customTestsResourceService
    ) {
    $this->connection = $connection;
    $this->messenger = $messenger;
    $this->timeInterface = $timeInterface;
    $this->customTestsResourceService = $customTestsResourceService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
          $container->get('database'),
          $container->get('messenger'),
          $container->get('datetime.time'),
          $container->get('custom_tests.load_resource.service')
      );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'custom_tests_filter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $session_filters = $this->getRequest()->getSession()->get('custom_tests_overview_filter', []);

    $form['filters'] = [
      '#type' => 'details',
      '#title' => $this->t('Filter log messages'),
      '#open' => TRUE,
      '#attached' => [
        'library' => [
          'testsuite/testsuite.filters',
        ],
      ],
    ];

    $form['filters']['filters-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'testsuite-tests-filter-form-wrapper',
      ],
    ];

    $actionDropdown = $form_state->hasValue('action') ? $form_state->getValue('action') : '';
    $action_dropdown = !empty($session_filters['action']) ? $session_filters['action'] : $actionDropdown;

    $form['filters']['filters-container']['action-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'testsuite-tests-action-container',
      ],
    ];
    $form['filters']['filters-container']['action-container']['action'] = [
      '#title' => 'Actions',
      '#type' => 'select',
      '#multiple' => FALSE,
      '#size' => 8,
      '#options' => [
        'filter' => $this->t('Filter'),
        'test' => $this->t('Run Test'),
      ],
      '#default_value' => $action_dropdown,
    ];

    $testDropdown = $form_state->hasValue('test') ? $form_state->getValue('test') : '';
    $test_dropdown = !empty($session_filters['test']) ? $session_filters['test'] : $testDropdown;

    $form['filters']['filters-container']['tests-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'testsuite-tests-container',
      ],
    ];
    $form['filters']['filters-container']['tests-container']['test'] = [
      '#title' => 'Tests',
      '#type' => 'select',
      '#multiple' => TRUE,
      '#size' => 8,
      '#options' => $this->customTestsResourceService->getTests(),
      '#default_value' => $test_dropdown,
    ];

    $form['filters']['actions'] = [
      '#type' => 'actions',
      '#attributes' => ['class' => ['container-inline']],
    ];
    $form['filters']['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];
    if (!empty($session_filters)) {
      $form['filters']['actions']['reset'] = [
        '#type' => 'submit',
        '#value' => $this->t('Reset'),
        '#limit_validation_errors' => [],
        '#submit' => ['::resetForm'],
      ];
    }
    return $form;
  }

  /**
   * Selects just the second dropdown to be returned for re-rendering.
   *
   * @param array $form
   *   — An associative array containing the structure of the form.
   *
   * @return array
   *   The renderable element.
   */
  public function getModulesCallback($form) {
    return $form['filters']['filters-container']['module-container'];
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if ($form_state->isValueEmpty('action')) {
      $form_state->setErrorByName('action', $this->t('You must select something to filter by.'));
    }
    if ($form_state->getValue('test') == []) {
      $form_state->setErrorByName('test', $this->t('You must select something to filter by.'));
    }
    foreach ($form_state->getValue('test') as $test) {
      if (!preg_match($this->regex['string'], $test)) {
        $form_state->setErrorByName('test', $this->t('Invalid option.'));
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $session_filters = $this->getRequest()->getSession()->get('custom_tests_overview_filter', []);

    if ($form_state->getValue('action') == 'test') {
      $files = $this->customTestsResourceService->getResource();
      foreach ($form_state->getValue('test') as $test) {
        if (count($files) > 0) {
          foreach ($files as $file) {
            $classFile = basename($file, '.php');
            if ($test == explode(".", $classFile)[0]) {
              $class = '\Drupal\custom_tests\CustomTSTests\\' . $classFile;
              include_once $file;
              if (class_exists($class)) {
                $obj = new $class();
                $request = $this->getRequest();
                $results = $obj->runTest($request);
                $this->connection->insert('custom_test_item')
                  ->fields(
                  [
                    'test' => $test,
                    'error_report' => $results,
                    'created' => $this->timeInterface->getRequestTime(),
                  ]
                )
                  ->execute();
              }
            }
          }
        }
      }
    }

    foreach ($this->filters as $name) {
      if ($form_state->hasValue($name)) {
        $session_filters[$name] = $form_state->getValue($name);
      }
    }
    $this->getRequest()->getSession()->set('custom_tests_overview_filter', $session_filters);
  }

  /**
   * Resets the filter form.
   */
  public function resetForm() {
    $this->getRequest()->getSession()->remove('custom_tests_overview_filter');
  }

}
